 /* ////////////////////////////////////////////////////////////////////////////
** File:      GSM_control.ino
* \mainpage GSM_control.ino
* \author    Guido Ottaviani-->guido@guiott.com<--
* \version 0.9.1
* \date 09/15
* \details 
 *
-------------------------------------------------------------------------------
\copyright 2015-2015 Guido Ottaviani
guido@guiott.com

    GSM_control.ino is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    GSM_control.ino is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GSM_control.ino.  If not, see <http://www.gnu.org/licenses/>.

-------------------------------------------------------------------------------

Starting from the original examples, this is the GUIOTT version of a sketch to test in the real world
the features of a GSM-GPRS shield. 
The focus here is on the GSM capabilities given by the SIM900 module, using this board
http://www.banggood.com/SIM900-Quad-band-GSM-GPRS-Shield-Development-Board-For-Arduino-p-964229.html

Using other boards requires just little changes on pin assignment, the commands are the same.

It uses a slightly modified version of the Marco Martines library to speed up the development
https://github.com/MarcoMartines/GSM-GPRS-GPS-Shield

GSM Shield for Arduino
www.open-electronics.org
this code is based on the example of Arduino Labs.
*/

#include "SIM900.h"
#include <SoftwareSerial.h>
//We don't need the http functions. So we can disable the next line.
//#include "inetGSM.h"
#include "sms.h"
#include "call.h"
#include <EEPROM.h>

//To change pins for Software Serial, use the two lines in GSM.cpp.

//We have to create the classes for SMSs and calls.
CallGSM call;
SMSGSM sms;

byte stat=0;
int value=0;

//pin 7 = SW serial TX: _GSM_TXPIN_
//pin 8 = SW serial RX: _GSM_RXPIN_
//pin 9 = shield PwrKey: GSM_ON
//pin11 = Temporary output
//pin12 = Output 1
//pin13 = Output 2
//pinA0 = Analog In

const int TmpOut = 11;
const int Out1   = 12;
const int Out2   = 13;
const int AnalogIn = A0;

boolean started=false;

char phone_number[16]; // array for the phone number string
char TmpStr[120];

void setup()
{
     pinMode(TmpOut,OUTPUT);
     pinMode(Out1,OUTPUT);
     pinMode(Out2,OUTPUT);

     //Serial connection used for debug and status messages
     Serial.begin(19200);
     Serial.println("GSM Shield testing.");    
     //Start configuration of shield with baudrate.
     //For http uses is raccomanded to use 4800 or slower.
     if(gsm.begin(19200))
     {
        Serial.println("\nstatus=READY");
        started=true;
     }
     else 
     {
        Serial.println("\nstatus=IDLE");
     }

     if(started) 
     {
       //Enable this two lines if you want to send an SMS.
       //E.g.: to know if the board restarts after a blackout
       //if (sms.SendSMS("3471234567", "Arduino SMS"))
       //Serial.println("\nSMS sent OK");
     }
};

void loop()
{
    if(started) 
    {//Chekcs status of call
      stat=call.CallStatusWithAuth(phone_number,1,3);
      //If the incoming call is from an authorized number
      //saved on SIM in the positions range from 1 to 3.
      //writing 0, 0 means that every call is authorized.
      //it could be useful but check carefully your environment
      if((stat==CALL_NONE))
      {
        ReadSms();
      }
      else if((stat==CALL_INCOM_VOICE_AUTH) || (CheckGranted(phone_number)!=0xFF))
      {//if the caller is authorized (both superuser or normal user)
       //the TmpOut is temporary set to HIGH and a SMS is sent back to the caller
       //returning the analog value of AnalogIn port
          PrivacyPrint();
          Serial.println("");
          digitalWrite(TmpOut, HIGH);
          //Hang up the call.
          call.HangUp();
          delay(2000);
          digitalWrite(TmpOut, LOW);
          //Check the value of the input.
          value=analogRead(AnalogIn);
          //Convert the int to a string.
          itoa(value,TmpStr,10);
          //Send an SMS to the caller with
          //the value read previously.
          Serial.print("Sending pin ");
          Serial.print(AnalogIn);
          Serial.print(" analog value: ");
          Serial.print(TmpStr);
          Serial.println(" to calling phone");
          sms.SendSMS(phone_number,TmpStr);
      }
      else
      {
        PrivacyPrint();
        Serial.println("");
      }
}
};

